@@ -9,7 +9,7 @@
  */
 
 /*
- * $Id: main-hildon.c,v 1.3 2005/07/25 15:17:11 florian Exp $
+ * $Id: main-hildon.c,v 1.4 2005/08/15 15:26:44 florian Exp $
  *
  */
 
@@ -53,7 +53,7 @@
 #include "finddlg.h"
 
 #define MY_PIXMAPS_DIR "gpe-contacts/"
-#define ICON_PATH PREFIX "/share/icons/hicolor/26x26"
+#define ICON_PATH "/usr/share/icons/hicolor/26x26/hildon"
 
 #define SERVICE_NAME    "gpe_contacts"
 #define SERVICE_VERSION VERSION
